@@ -1,4 +1,4 @@
-from .core import FeatureDictManage
+from .core import FeatureDictManage, FeaturePreProcessing
 from .feature_column_def import IndicatorColumnDef
 from .feature_parse import ParseFeatureConfig
 from .feature_parse_keras import ParseFeatureConfig
